.. _about:

*************
About us
*************

The sections gives useful informations about the decision made to design the :code:`watex` project 

Project history
------------------

.. toctree::
   :maxdepth: 2
   
   Five minutes to understand the project genesis <five_min_understanding> 
   Project story <project_story>
   Mission and Goals <project_goals>

